/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   http://lammps.sandia.gov, Sandia National Laboratories
   Steve Plimpton, sjplimp@sandia.gov

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

/* ----------------------------------------------------------------------
   Contributing author: Nicolas Onofrio, Purdue University
   (nonofrio@purdue.edu)
------------------------------------------------------------------------- */

#ifdef COMPUTE_CLASS

ComputeStyle(laplacian,ComputeLap)

#else

#ifndef LMP_COMPUTE_LAPLACIAN_H
#define LMP_COMPUTE_LAPLACIAN_H

#include "compute.h"

namespace LAMMPS_NS {

class ComputeLap : public Compute {
 public:
  ComputeLap(class LAMMPS *, int, char **);
  ~ComputeLap();
  void init();
  void setup();
  void compute_peratom();

  virtual int pack_forward_comm(int, int *, double *, int, int *);
  virtual void unpack_forward_comm(int, int, double *);
  void get_names(char *, double *&);

 protected:
  double rc,norm,loc01,loc02;
  int groupbit1,groupbit2,nmax,flagbound,flagnorm;
  char *id_lap,*nfile;
  class Compute *laplacian;
  double *sumw;
 private:
};

}

#endif
#endif

